diff layer/TimeInstantLayer.cpp @ 585:f4960f8ce798 debug-output

Convert many cerrs to DEBUGs
author Chris Cannam
date Mon, 16 May 2011 17:19:25 +0100
parents a4ba6c96b66d
children 4806715f7a19
line wrap: on
line diff
--- a/layer/TimeInstantLayer.cpp	Thu May 12 17:31:43 2011 +0100
+++ b/layer/TimeInstantLayer.cpp	Mon May 16 17:19:25 2011 +0100
@@ -60,7 +60,7 @@
     connectSignals(m_model);
 
 #ifdef DEBUG_TIME_INSTANT_LAYER
-    std::cerr << "TimeInstantLayer::setModel(" << model << ")" << std::endl;
+    DEBUG << "TimeInstantLayer::setModel(" << model << ")" << endl;
 #endif
 
     if (m_model && m_model->getRDFTypeURI().endsWith("Segment")) {
@@ -363,8 +363,8 @@
 	oddBrushColour.setAlpha(100);
     }
 
 //    std::cerr << "TimeInstantLayer::paint: resolution is "
 //	      << m_model->getResolution() << " frames" << std::endl;
 
     QPoint localPos;
     long illuminateFrame = -1;
@@ -469,7 +469,7 @@
 TimeInstantLayer::drawStart(View *v, QMouseEvent *e)
 {
 #ifdef DEBUG_TIME_INSTANT_LAYER
-    std::cerr << "TimeInstantLayer::drawStart(" << e->x() << ")" << std::endl;
+    DEBUG << "TimeInstantLayer::drawStart(" << e->x() << ")" << endl;
 #endif
 
     if (!m_model) return;
@@ -492,7 +492,7 @@
 TimeInstantLayer::drawDrag(View *v, QMouseEvent *e)
 {
 #ifdef DEBUG_TIME_INSTANT_LAYER
-    std::cerr << "TimeInstantLayer::drawDrag(" << e->x() << ")" << std::endl;
+    DEBUG << "TimeInstantLayer::drawDrag(" << e->x() << ")" << endl;
 #endif
 
     if (!m_model || !m_editing) return;
@@ -509,7 +509,7 @@
 TimeInstantLayer::drawEnd(View *, QMouseEvent *e)
 {
 #ifdef DEBUG_TIME_INSTANT_LAYER
-    std::cerr << "TimeInstantLayer::drawEnd(" << e->x() << ")" << std::endl;
+    DEBUG << "TimeInstantLayer::drawEnd(" << e->x() << ")" << endl;
 #endif
     if (!m_model || !m_editing) return;
     QString newName = tr("Add Point at %1 s")
@@ -570,7 +570,7 @@
 TimeInstantLayer::editStart(View *v, QMouseEvent *e)
 {
 #ifdef DEBUG_TIME_INSTANT_LAYER
-    std::cerr << "TimeInstantLayer::editStart(" << e->x() << ")" << std::endl;
+    DEBUG << "TimeInstantLayer::editStart(" << e->x() << ")" << endl;
 #endif
 
     if (!m_model) return;
@@ -592,7 +592,7 @@
 TimeInstantLayer::editDrag(View *v, QMouseEvent *e)
 {
 #ifdef DEBUG_TIME_INSTANT_LAYER
-    std::cerr << "TimeInstantLayer::editDrag(" << e->x() << ")" << std::endl;
+    DEBUG << "TimeInstantLayer::editDrag(" << e->x() << ")" << endl;
 #endif
 
     if (!m_model || !m_editing) return;
@@ -615,7 +615,7 @@
 TimeInstantLayer::editEnd(View *, QMouseEvent *e)
 {
 #ifdef DEBUG_TIME_INSTANT_LAYER
-    std::cerr << "TimeInstantLayer::editEnd(" << e->x() << ")" << std::endl;
+    DEBUG << "TimeInstantLayer::editEnd(" << e->x() << ")" << endl;
 #endif
     if (!m_model || !m_editing) return;
     if (m_editingCommand) {
@@ -363,8 +363,8 @@
     }
 
-//    std::cerr << "TimeInstantLayer::paint: resolution is "
-//	      << m_model->getResolution() << " frames" << std::endl;
+//    DEBUG << "TimeInstantLayer::paint: resolution is "
+//	      << m_model->getResolution() << " frames" << endl;
 
     QPoint localPos;